LockedPackage

Struct LockedPackage 

pub struct LockedPackage {
    pub name: PackageName,
    pub version: Version,
    pub digest: Digest,
    pub registry: RegistryUri,
    pub repository: String,
    pub dependencies: Vec<LockedDependency>,
    pub dependants: usize,
}
Captures immutable metadata about a given package

It is used to ensure that future installations will use the exact same dependencies.

Fields

name: PackageName

The name of the package

version: Version

The exact version of the package

digest: Digest

The cryptographic digest of the package contents

registry: RegistryUri

The URI of the registry that contains the package

repository: String

The identifier of the repository where the package was published

dependencies: Vec<LockedDependency>

Names of dependency packages

dependants: usize

Count of dependant packages in the current graph

This is used to detect when an entry can be safely removed from the lockfile.

Implementations

Source

impl LockedPackage

pub fn lock( package: &Package, registry: RegistryUri, repository: String, dependants: usize, ) -> Self

Captures the source, version and checksum of a Package for use in reproducible installs

pub fn validate(&self, package: &Package) -> Result<()>

Validates if another LockedPackage matches this one