pub struct LockedPackage {
pub name: PackageName,
pub version: Version,
pub digest: Digest,
pub registry: RegistryUri,
pub repository: String,
pub dependencies: Vec<LockedDependency>,
pub dependants: usize,
}Expand description
Captures immutable metadata about a given package
It is used to ensure that future installations will use the exact same dependencies.
Fields
name: PackageNameThe name of the package
version: VersionThe exact version of the package
digest: DigestThe cryptographic digest of the package contents
registry: RegistryUriThe URI of the registry that contains the package
repository: StringThe identifier of the repository where the package was published
dependencies: Vec<LockedDependency>Names of dependency packages
dependants: usizeCount of dependant packages in the current graph
This is used to detect when an entry can be safely removed from the lockfile.
Implementations
Sourceimpl LockedPackage
impl LockedPackage